@@ -124,9 +124,6 @@ namespace Oxygen
         //! uninstall shadow X11 property on given widget
         void uninstallX11Shadows( QWidget* ) const;
 
-        //! uninstall shadow X11 property on given window
-        void uninstallX11Shadows( WId ) const;
-
         private:
 
         //! helper
