@@ -371,6 +371,9 @@ void Client::updateInputWindow()
     if (brokenQtInputHandling)
         return;
 
+    if (!Xcb::Extensions::self()->isShapeInputAvailable())
+        return;
+
     QRegion region;
 
     if (!noBorder()) {
@@ -450,6 +453,7 @@ void Client::createDecoration(const QRect& oldgeom)
     connect(this, SIGNAL(shadeChanged()), decoration, SLOT(shadeChange()));
     connect(this, SIGNAL(desktopChanged()), decoration, SLOT(desktopChange()));
     connect(this, SIGNAL(captionChanged()), decoration, SLOT(captionChange()));
+    connect(this, SIGNAL(iconChanged()), decoration, SLOT(iconChange()));
     connect(this, SIGNAL(activeChanged()), decoration, SLOT(activeChange()));
     connect(this, SIGNAL(clientMaximizedStateChanged(KWin::Client*,KDecorationDefines::MaximizeMode)),
             decoration, SLOT(maximizeChange()));
@@ -2426,7 +2430,7 @@ QRect Client::decorationRect() const
     }
 }
 
-KDecorationDefines::Position Client::titlebarPosition()
+KDecorationDefines::Position Client::titlebarPosition() const
 {
     Position titlePos = PositionCenter; // PositionTop is returned by the default implementation
                                         // this will hint errors in the metaobject usage ;-)
