@@ -48,7 +48,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QLabel>
 #include <KComboBox>
 #include <QVBoxLayout>
-#include <KGlobalSettings>
 
 #include "config-workspace.h"
 
@@ -76,6 +75,15 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #undef INT8
 #undef INT32
 
+static bool isMultiHead()
+{
+    QByteArray multiHead = qgetenv("KDE_MULTIHEAD");
+    if (!multiHead.isEmpty()) {
+        return (multiHead.toLower() == "true");
+    }
+    return true;
+}
+
 namespace KWin
 {
 
@@ -495,7 +503,7 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
     int number_of_screens = ScreenCount(dpy);
 
     // multi head
-    if (number_of_screens != 1 && KGlobalSettings::isMultiHead()) {
+    if (number_of_screens != 1 && isMultiHead()) {
         KWin::is_multihead = true;
         KWin::screen_number = DefaultScreen(dpy);
         int pos; // Temporarily needed to reconstruct DISPLAY var if multi-head
